// SPDX-License-Identifier: GPL-3.0-or-later
/*
 * Qt mutizone MQTT thermostat
 *
 * Copyright (C) 2019 Richard Genoud
 *
 */

#include <QLoggingCategory>
#include <QStringList>
#include <QJsonDocument>
#include <QJsonObject>
#include <QJsonValue>


#include "mqttclient.h"
#include "qmqtt.h"

MQTTSubcriber::MQTTSubcriber(const QHostAddress& host, const quint16 port,
			     QObject* parent) : QMQTT::Client(host, port, parent)
{
	connect(this, &MQTTSubcriber::connected, this, &MQTTSubcriber::onConnected);
	connect(this, &MQTTSubcriber::subscribed, this, &MQTTSubcriber::onSubscribed);
	connect(this, &MQTTSubcriber::received, this, &MQTTSubcriber::onReceived);
	m_sensor_topics << QString::fromUtf8("sensors/chambre_so/xiaomi");
	m_sensor_topics << QString::fromUtf8("sensors/chambre_rico/xiaomi");
	m_sensor_topics << QString::fromUtf8("sensors/salon/xiaomi");
	m_sensor_topics << QString::fromUtf8("sensors/salle_de_bains/xiaomi");
	m_availability_topics << QString::fromUtf8("sensors/chambre_so/availability");
	m_availability_topics << QString::fromUtf8("sensors/chambre_rico/availability");
	m_availability_topics << QString::fromUtf8("sensors/salon/availability");
	m_availability_topics << QString::fromUtf8("sensors/salle_de_bains/availability");

	qDebug() << "created" << endl;
}

MQTTSubcriber::~MQTTSubcriber() {
}

void MQTTSubcriber::onConnected()
{
	qDebug() << "connected" << endl;
	this->subscribe("sensors/#", 1);
}

void MQTTSubcriber::onSubscribed(const QString& topic)
{
	qDebug() << "subscribed " << topic << endl;
}

void MQTTSubcriber::onReceived(const QMQTT::Message& message)
{
	QJsonDocument sensorData;

	qDebug() << "publish received: \"" << QString::fromUtf8(message.payload())
		<< "\"" << " from: " << message.topic() << endl;

	for (int i = 0; i < m_sensor_topics.size(); ++i) {
		if (m_sensor_topics.at(i) == message.topic()) {
			qDebug() << "this is for us !" << endl;
			sensorData = QJsonDocument::fromJson(message.payload());
			if (!sensorData.isObject()) {
				qWarning() << "malformed JSON data" << endl;
				goto out;
			}
			QJsonObject obj(sensorData.object());
			QJsonValue val = obj["temperature"];

			qDebug() << val.toDouble() << endl;

			break;
		}
	}
out:
	return;
}

/* vim: set tabstop=8 shiftwidth=8 softtabstop=0 noexpandtab: */
